.. highlight:: shell

============
Installation
============


Stable release
--------------

To install bonndit via pip, run this command in your terminal:

.. code-block:: console

    $ pip install bonndit

To install bonndit via conda, run this command in your terminal:

.. code-block:: console

    $ conda install bonndit -c xderes -c conda-forge


From sources
------------

The sources for bonndit can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/MedVisBon/bonndit

Or download the `tarball`_:

.. code-block:: console

    $ curl  -OL https://github.com/MedVisBonn/bonndit/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/MedVisBonn/bonndit
.. _tarball: https://github.com/MedVisBonn/bonndit/tarball/master
